/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:47:35-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define ENVIRONMENT_LABEL_1_3 5
#define DEBUGGING_LABEL_1_2 4
#define FREE_REFERENCES_LABEL_1_0 4
#define NUMBER_OF_LINKER_SECTIONS_1_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define LABEL_2_9 7
#define LABEL_2_10 9
#define LABEL_2_6 11
#define LABEL_2_8 13
#define LABEL_2_14 15
#define LABEL_2_15 17
#define LABEL_2_12 19
#define LABEL_2_16 21
#define LABEL_2_20 23
#define LABEL_2_21 25
#define LABEL_2_22 27
#define LABEL_2_23 29
#define LABEL_2_24 31
#define LABEL_2_25 33
#define LABEL_2_26 35
#define LABEL_2_27 37
#define LABEL_2_28 39
#define LABEL_2_29 41
#define LABEL_2_18 43
#define LABEL_2_19 45
#define LABEL_2_31 47
#define LABEL_2_32 49
#define LABEL_2_35 51
#define LABEL_2_38 53
#define LABEL_2_39 55
#define LABEL_2_40 57
#define LABEL_2_42 59
#define ENVIRONMENT_LABEL_2_3 115
#define DEBUGGING_LABEL_2_2 114
#define OBJECT_2_11 113
#define OBJECT_2_10 112
#define OBJECT_2_9 111
#define OBJECT_2_8 110
#define OBJECT_2_7 109
#define OBJECT_2_6 108
#define OBJECT_2_5 107
#define OBJECT_2_4 106
#define OBJECT_2_3 105
#define OBJECT_2_2 104
#define OBJECT_2_1 103
#define OBJECT_2_0 102
#define EXECUTE_CACHE_2_44 61
#define EXECUTE_CACHE_2_43 63
#define EXECUTE_CACHE_2_41 65
#define EXECUTE_CACHE_2_37 67
#define EXECUTE_CACHE_2_36 69
#define EXECUTE_CACHE_2_34 71
#define EXECUTE_CACHE_2_33 73
#define EXECUTE_CACHE_2_30 75
#define EXECUTE_CACHE_2_17 77
#define EXECUTE_CACHE_2_13 79
#define EXECUTE_CACHE_2_11 81
#define EXECUTE_CACHE_2_7 83
#define FREE_REFERENCE_2_13 86
#define FREE_REFERENCE_2_12 87
#define FREE_REFERENCE_2_11 88
#define FREE_REFERENCE_2_10 89
#define FREE_REFERENCE_2_9 90
#define FREE_REFERENCE_2_8 91
#define FREE_REFERENCE_2_7 92
#define FREE_REFERENCE_2_6 93
#define FREE_REFERENCE_2_5 94
#define FREE_REFERENCE_2_4 95
#define FREE_REFERENCE_2_3 96
#define FREE_REFERENCE_2_2 97
#define FREE_REFERENCE_2_1 98
#define FREE_REFERENCE_2_0 99
#define FREE_ASSIGNMENT_2_0 101
#define FREE_REFERENCES_LABEL_2_0 60
#define NUMBER_OF_LINKER_SECTIONS_2_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd161;
  machine_word Wrd154;
  machine_word Wrd156;
  machine_word Wrd157;
  machine_word Wrd148;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd149;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd146;
  machine_word Wrd139;
  machine_word Wrd141;
  machine_word Wrd142;
  machine_word Wrd133;
  machine_word Wrd138;
  machine_word Wrd137;
  machine_word Wrd134;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd131;
  machine_word Wrd124;
  machine_word Wrd126;
  machine_word Wrd127;
  machine_word Wrd118;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd119;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd116;
  machine_word Wrd109;
  machine_word Wrd111;
  machine_word Wrd112;
  machine_word Wrd103;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd104;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd101;
  machine_word Wrd94;
  machine_word Wrd96;
  machine_word Wrd97;
  machine_word Wrd88;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd86;
  machine_word Wrd79;
  machine_word Wrd81;
  machine_word Wrd82;
  machine_word Wrd73;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd74;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd71;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd67;
  machine_word Wrd58;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd59;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd49;
  machine_word Wrd51;
  machine_word Wrd52;
  machine_word Wrd43;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd37;
  machine_word Wrd28;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto initialize_packageB_36;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_2_9);
      goto label_38;

    case 3:
      current_block = (Rpc - LABEL_2_10);
      goto label_39;

    case 4:
      current_block = (Rpc - LABEL_2_6);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_2_8);
      goto continuation_35;

    case 6:
      current_block = (Rpc - LABEL_2_14);
      goto label_40;

    case 7:
      current_block = (Rpc - LABEL_2_15);
      goto label_41;

    case 8:
      current_block = (Rpc - LABEL_2_12);
      goto continuation_1;

    case 9:
      current_block = (Rpc - LABEL_2_16);
      goto continuation_0;

    case 10:
      current_block = (Rpc - LABEL_2_20);
      goto label_42;

    case 11:
      current_block = (Rpc - LABEL_2_21);
      goto label_43;

    case 12:
      current_block = (Rpc - LABEL_2_22);
      goto label_44;

    case 13:
      current_block = (Rpc - LABEL_2_23);
      goto label_45;

    case 14:
      current_block = (Rpc - LABEL_2_24);
      goto label_46;

    case 15:
      current_block = (Rpc - LABEL_2_25);
      goto label_47;

    case 16:
      current_block = (Rpc - LABEL_2_26);
      goto label_48;

    case 17:
      current_block = (Rpc - LABEL_2_27);
      goto label_49;

    case 18:
      current_block = (Rpc - LABEL_2_28);
      goto label_50;

    case 19:
      current_block = (Rpc - LABEL_2_29);
      goto label_51;

    case 20:
      current_block = (Rpc - LABEL_2_18);
      goto continuation_25;

    case 21:
      current_block = (Rpc - LABEL_2_19);
      goto continuation_24;

    case 22:
      current_block = (Rpc - LABEL_2_31);
      goto continuation_27;

    case 23:
      current_block = (Rpc - LABEL_2_32);
      goto continuation_26;

    case 24:
      current_block = (Rpc - LABEL_2_35);
      goto continuation_28;

    case 25:
      current_block = (Rpc - LABEL_2_38);
      goto continuation_29;

    case 26:
      current_block = (Rpc - LABEL_2_39);
      goto label_52;

    case 27:
      current_block = (Rpc - LABEL_2_40);
      goto continuation_30;

    case 28:
      current_block = (Rpc - LABEL_2_42);
      goto continuation_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packageB_54)
DEFLABEL (initialize_packageB_36)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_2_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_2_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_2_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_17]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_2_16);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_19]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_4]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_77;
  Wrd13 = Wrd17;

DEFLABEL (label_76)
  (Wrd22.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd21.pObj) = (& (Rhp [-2]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd21.pObj)));
  (Wrd26.Obj) = (current_block [OBJECT_2_2]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_5]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_75;
  Wrd28 = Wrd32;

DEFLABEL (label_74)
  (Wrd37.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (Wrd41.Obj) = (current_block [OBJECT_2_3]);
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd44.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_6]));
  (Wrd47.Obj) = ((Wrd44.pObj) [0]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if ((Wrd48.uLng) == 50)
    goto label_73;
  Wrd43 = Wrd47;

DEFLABEL (label_72)
  (Wrd52.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd43.Obj);
  (* (Rhp++)) = (Wrd52.Obj);
  (Wrd51.pObj) = (& (Rhp [-2]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd51.pObj)));
  (Wrd56.Obj) = (current_block [OBJECT_2_4]);
  (* (Rhp++)) = (Wrd56.Obj);
  (* (Rhp++)) = (Wrd49.Obj);
  (Wrd54.pObj) = (& (Rhp [-2]));
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd54.pObj)));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd59.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_7]));
  (Wrd62.Obj) = ((Wrd59.pObj) [0]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if ((Wrd63.uLng) == 50)
    goto label_71;
  Wrd58 = Wrd62;

DEFLABEL (label_70)
  (Wrd67.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd58.Obj);
  (* (Rhp++)) = (Wrd67.Obj);
  (Wrd66.pObj) = (& (Rhp [-2]));
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd66.pObj)));
  (Wrd71.Obj) = (current_block [OBJECT_2_5]);
  (* (Rhp++)) = (Wrd71.Obj);
  (* (Rhp++)) = (Wrd64.Obj);
  (Wrd69.pObj) = (& (Rhp [-2]));
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd69.pObj)));
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd74.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_8]));
  (Wrd77.Obj) = ((Wrd74.pObj) [0]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if ((Wrd78.uLng) == 50)
    goto label_69;
  Wrd73 = Wrd77;

DEFLABEL (label_68)
  (Wrd82.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd73.Obj);
  (* (Rhp++)) = (Wrd82.Obj);
  (Wrd81.pObj) = (& (Rhp [-2]));
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd81.pObj)));
  (Wrd86.Obj) = (current_block [OBJECT_2_6]);
  (* (Rhp++)) = (Wrd86.Obj);
  (* (Rhp++)) = (Wrd79.Obj);
  (Wrd84.pObj) = (& (Rhp [-2]));
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd84.pObj)));
  (* (--Rsp)) = (Wrd85.Obj);
  (Wrd89.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_9]));
  (Wrd92.Obj) = ((Wrd89.pObj) [0]);
  (Wrd93.uLng) = (OBJECT_TYPE (Wrd92.Obj));
  if ((Wrd93.uLng) == 50)
    goto label_67;
  Wrd88 = Wrd92;

DEFLABEL (label_66)
  (Wrd97.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd88.Obj);
  (* (Rhp++)) = (Wrd97.Obj);
  (Wrd96.pObj) = (& (Rhp [-2]));
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd96.pObj)));
  (Wrd101.Obj) = (current_block [OBJECT_2_7]);
  (* (Rhp++)) = (Wrd101.Obj);
  (* (Rhp++)) = (Wrd94.Obj);
  (Wrd99.pObj) = (& (Rhp [-2]));
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd99.pObj)));
  (* (--Rsp)) = (Wrd100.Obj);
  (Wrd104.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_10]));
  (Wrd107.Obj) = ((Wrd104.pObj) [0]);
  (Wrd108.uLng) = (OBJECT_TYPE (Wrd107.Obj));
  if ((Wrd108.uLng) == 50)
    goto label_65;
  Wrd103 = Wrd107;

DEFLABEL (label_64)
  (Wrd112.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd103.Obj);
  (* (Rhp++)) = (Wrd112.Obj);
  (Wrd111.pObj) = (& (Rhp [-2]));
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd111.pObj)));
  (Wrd116.Obj) = (current_block [OBJECT_2_8]);
  (* (Rhp++)) = (Wrd116.Obj);
  (* (Rhp++)) = (Wrd109.Obj);
  (Wrd114.pObj) = (& (Rhp [-2]));
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd114.pObj)));
  (* (--Rsp)) = (Wrd115.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_11]));
  (Wrd122.Obj) = ((Wrd119.pObj) [0]);
  (Wrd123.uLng) = (OBJECT_TYPE (Wrd122.Obj));
  if ((Wrd123.uLng) == 50)
    goto label_63;
  Wrd118 = Wrd122;

DEFLABEL (label_62)
  (Wrd127.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd118.Obj);
  (* (Rhp++)) = (Wrd127.Obj);
  (Wrd126.pObj) = (& (Rhp [-2]));
  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd126.pObj)));
  (Wrd131.Obj) = (current_block [OBJECT_2_9]);
  (* (Rhp++)) = (Wrd131.Obj);
  (* (Rhp++)) = (Wrd124.Obj);
  (Wrd129.pObj) = (& (Rhp [-2]));
  (Wrd130.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd129.pObj)));
  (* (--Rsp)) = (Wrd130.Obj);
  (Wrd134.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_12]));
  (Wrd137.Obj) = ((Wrd134.pObj) [0]);
  (Wrd138.uLng) = (OBJECT_TYPE (Wrd137.Obj));
  if ((Wrd138.uLng) == 50)
    goto label_61;
  Wrd133 = Wrd137;

DEFLABEL (label_60)
  (Wrd142.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd133.Obj);
  (* (Rhp++)) = (Wrd142.Obj);
  (Wrd141.pObj) = (& (Rhp [-2]));
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd141.pObj)));
  (Wrd146.Obj) = (current_block [OBJECT_2_10]);
  (* (Rhp++)) = (Wrd146.Obj);
  (* (Rhp++)) = (Wrd139.Obj);
  (Wrd144.pObj) = (& (Rhp [-2]));
  (Wrd145.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd144.pObj)));
  (* (--Rsp)) = (Wrd145.Obj);
  (Wrd149.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_13]));
  (Wrd152.Obj) = ((Wrd149.pObj) [0]);
  (Wrd153.uLng) = (OBJECT_TYPE (Wrd152.Obj));
  if ((Wrd153.uLng) == 50)
    goto label_59;
  Wrd148 = Wrd152;

DEFLABEL (label_58)
  (Wrd157.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd148.Obj);
  (* (Rhp++)) = (Wrd157.Obj);
  (Wrd156.pObj) = (& (Rhp [-2]));
  (Wrd154.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd156.pObj)));
  (Wrd161.Obj) = (current_block [OBJECT_2_11]);
  (* (Rhp++)) = (Wrd161.Obj);
  (* (Rhp++)) = (Wrd154.Obj);
  (Wrd159.pObj) = (& (Rhp [-2]));
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd159.pObj)));
  (* (--Rsp)) = (Wrd160.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_30]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_2_19);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_34]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_2_18);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_32]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_33]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_2_32);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_37]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_2_31);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_35]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_36]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_2_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_38]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_36]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_2_38);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_57;

DEFLABEL (label_56)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_55)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_40]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_41]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_2_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_43]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_2_42);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd5.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_44]));

DEFLABEL (label_57)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_56;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_39])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_52)
  goto label_55;

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_29])), (Wrd149.pObj));

DEFLABEL (label_51)
  (Wrd148.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_28])), (Wrd134.pObj));

DEFLABEL (label_50)
  (Wrd133.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_27])), (Wrd119.pObj));

DEFLABEL (label_49)
  (Wrd118.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_26])), (Wrd104.pObj));

DEFLABEL (label_48)
  (Wrd103.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_25])), (Wrd89.pObj));

DEFLABEL (label_47)
  (Wrd88.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_24])), (Wrd74.pObj));

DEFLABEL (label_46)
  (Wrd73.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_23])), (Wrd59.pObj));

DEFLABEL (label_45)
  (Wrd58.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_22])), (Wrd44.pObj));

DEFLABEL (label_44)
  (Wrd43.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_21])), (Wrd29.pObj));

DEFLABEL (label_43)
  (Wrd28.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_20])), (Wrd14.pObj));

DEFLABEL (label_42)
  (Wrd13.Obj) = Rvl;
  goto label_76;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_2_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_85;
  Wrd8 = Wrd12;

DEFLABEL (label_84)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_83;
  Wrd14 = Wrd18;

DEFLABEL (label_82)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_11]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_2_8);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_81;
  Wrd5 = Wrd9;

DEFLABEL (label_80)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_3]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_79;
  Wrd11 = Wrd15;

DEFLABEL (label_78)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_11]));

DEFLABEL (label_79)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_15])), (Wrd12.pObj));

DEFLABEL (label_41)
  (Wrd11.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_14])), (Wrd6.pObj));

DEFLABEL (label_40)
  (Wrd5.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_10])), (Wrd15.pObj));

DEFLABEL (label_39)
  (Wrd14.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_85)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_9])), (Wrd9.pObj));

DEFLABEL (label_38)
  (Wrd8.Obj) = Rvl;
  goto label_84;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 7
#define DEBUGGING_LABEL_3_2 6
#define OBJECT_3_1 5
#define OBJECT_3_0 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto cstate_echo_inputP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cstate_echo_inputP_3)
DEFLABEL (cstate_echo_inputP_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_3_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_7 5
#define LABEL_4_5 7
#define LABEL_4_6 9
#define ENVIRONMENT_LABEL_4_3 19
#define DEBUGGING_LABEL_4_2 18
#define OBJECT_4_0 17
#define EXECUTE_CACHE_4_9 11
#define EXECUTE_CACHE_4_8 13
#define FREE_REFERENCE_4_0 16
#define FREE_REFERENCES_LABEL_4_0 10
#define NUMBER_OF_LINKER_SECTIONS_4_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto save_console_input_2;

    case 1:
      current_block = (Rpc - LABEL_4_7);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_4_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_4_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (save_console_input_6)
DEFLABEL (save_console_input_2)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_8;
  Wrd11 = Wrd15;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_4_5);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_7])), (Wrd12.pObj));

DEFLABEL (label_4)
  (Wrd11.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define LABEL_5_7 7
#define LABEL_5_9 9
#define LABEL_5_10 11
#define LABEL_5_14 13
#define LABEL_5_13 15
#define LABEL_5_17 17
#define LABEL_5_12 19
#define LABEL_5_20 21
#define LABEL_5_19 23
#define LABEL_5_22 25
#define LABEL_5_16 27
#define ENVIRONMENT_LABEL_5_3 47
#define DEBUGGING_LABEL_5_2 46
#define OBJECT_5_0 45
#define EXECUTE_CACHE_5_23 29
#define EXECUTE_CACHE_5_21 31
#define EXECUTE_CACHE_5_18 33
#define EXECUTE_CACHE_5_15 35
#define EXECUTE_CACHE_5_11 37
#define EXECUTE_CACHE_5_8 39
#define EXECUTE_CACHE_5_6 41
#define FREE_REFERENCE_5_0 44
#define FREE_REFERENCES_LABEL_5_0 28
#define NUMBER_OF_LINKER_SECTIONS_5_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto reset_console_10;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_5_7);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_5_9);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_5_10);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_5_14);
      goto label_12;

    case 6:
      current_block = (Rpc - LABEL_5_13);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_5_17);
      goto label_14;

    case 8:
      current_block = (Rpc - LABEL_5_12);
      goto continuation_5;

    case 9:
      current_block = (Rpc - LABEL_5_20);
      goto label_13;

    case 10:
      current_block = (Rpc - LABEL_5_19);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_5_22);
      goto label_15;

    case 12:
      current_block = (Rpc - LABEL_5_16);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reset_console_17)
DEFLABEL (reset_console_10)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_5_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_5_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_5_10);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_27;
  Wrd5 = Wrd9;

DEFLABEL (label_26)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_5_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 0);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_5_13);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_16]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_19;
  Wrd20 = Wrd24;

DEFLABEL (label_18)
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_18]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_5_16);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_23]));

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_17])), (Wrd21.pObj));

DEFLABEL (label_14)
  (Wrd20.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_20)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_25)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_24;
  Wrd8 = Wrd12;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_21]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_5_19);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_22;
  Wrd7 = Wrd11;

DEFLABEL (label_21)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_21]));

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_22])), (Wrd8.pObj));

DEFLABEL (label_15)
  (Wrd7.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_20])), (Wrd9.pObj));

DEFLABEL (label_13)
  (Wrd8.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_14])), (Wrd6.pObj));

DEFLABEL (label_12)
  (Wrd5.Obj) = Rvl;
  goto label_26;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_5_12);
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define ENVIRONMENT_LABEL_6_3 13
#define DEBUGGING_LABEL_6_2 12
#define OBJECT_6_0 11
#define EXECUTE_CACHE_6_7 7
#define EXECUTE_CACHE_6_6 9
#define FREE_REFERENCES_LABEL_6_0 6
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto make_cstate_1;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_cstate_4)
DEFLABEL (make_cstate_1)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd5.Obj) = (current_block [OBJECT_6_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_6_5);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_6_0]);
  (Rsp [3]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_7 5
#define LABEL_7_5 7
#define LABEL_7_9 9
#define LABEL_7_10 11
#define LABEL_7_11 13
#define ENVIRONMENT_LABEL_7_3 27
#define DEBUGGING_LABEL_7_2 26
#define OBJECT_7_2 25
#define OBJECT_7_1 24
#define OBJECT_7_0 23
#define EXECUTE_CACHE_7_8 15
#define EXECUTE_CACHE_7_6 17
#define FREE_ASSIGNMENT_7_2 20
#define FREE_ASSIGNMENT_7_1 21
#define FREE_ASSIGNMENT_7_0 22
#define FREE_REFERENCES_LABEL_7_0 14
#define NUMBER_OF_LINKER_SECTIONS_7_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto set_console_i_o_portB_2;

    case 1:
      current_block = (Rpc - LABEL_7_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_7_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_7_9);
      goto label_4;

    case 4:
      current_block = (Rpc - LABEL_7_10);
      goto label_5;

    case 5:
      current_block = (Rpc - LABEL_7_11);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_console_i_o_portB_8)
DEFLABEL (set_console_i_o_portB_2)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_18;
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_7]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (current_block [OBJECT_7_0]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_7_1]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_7_7);

DEFLABEL (label_18)
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_0]));
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd15.Obj) = ((Wrd7.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_17;

DEFLABEL (label_16)
  ((Wrd7.pObj) [0]) = (Wrd8.Obj);

DEFLABEL (label_15)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_1]));
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd27.Obj) = ((Wrd19.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_14;

DEFLABEL (label_13)
  ((Wrd19.pObj) [0]) = (Wrd20.Obj);

DEFLABEL (label_12)
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_2]));
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_11;

DEFLABEL (label_10)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_9)
  Rvl = (current_block [OBJECT_7_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_10;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_11])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_6)
  goto label_9;

DEFLABEL (label_14)
  if ((Wrd27.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_13;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_10])), (Wrd19.pObj), (Wrd20.Obj));

DEFLABEL (label_5)
  goto label_12;

DEFLABEL (label_17)
  if ((Wrd15.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_16;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_9])), (Wrd7.pObj), (Wrd8.Obj));

DEFLABEL (label_4)
  goto label_15;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define ENVIRONMENT_LABEL_8_3 12
#define DEBUGGING_LABEL_8_2 11
#define EXECUTE_CACHE_8_6 7
#define FREE_REFERENCE_8_0 10
#define FREE_REFERENCES_LABEL_8_0 6
#define NUMBER_OF_LINKER_SECTIONS_8_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto console_i_o_portP_0;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (console_i_o_portP_4)
DEFLABEL (console_i_o_portP_0)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_8_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define LABEL_9_9 7
#define LABEL_9_7 9
#define LABEL_9_12 11
#define LABEL_9_10 13
#define LABEL_9_16 15
#define LABEL_9_15 17
#define LABEL_9_13 19
#define ENVIRONMENT_LABEL_9_3 42
#define DEBUGGING_LABEL_9_2 41
#define OBJECT_9_1 40
#define OBJECT_9_0 39
#define EXECUTE_CACHE_9_21 21
#define EXECUTE_CACHE_9_20 23
#define EXECUTE_CACHE_9_19 25
#define EXECUTE_CACHE_9_18 27
#define EXECUTE_CACHE_9_17 29
#define EXECUTE_CACHE_9_14 31
#define EXECUTE_CACHE_9_11 33
#define EXECUTE_CACHE_9_8 35
#define EXECUTE_CACHE_9_6 37
#define FREE_REFERENCES_LABEL_9_0 20
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto operation_read_char_10;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_9_9);
      goto continuation_8;

    case 3:
      current_block = (Rpc - LABEL_9_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_9_12);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_9_10);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_9_16);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_9_15);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_9_13);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (operation_read_char_13)
DEFLABEL (operation_read_char_10)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_9_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_9_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;

DEFLABEL (label_14)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_9_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;

DEFLABEL (label_18)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_15]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_16]))));
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_17]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_9_16);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_18]));

DEFLABEL (label_16)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_17)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_19]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_9_9);
  goto label_14;

DEFLABEL (label_19)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_13]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_9_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_9_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_21]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_9_12);
  goto label_18;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_9_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_9_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_20]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_6 5
#define LABEL_10_9 7
#define LABEL_10_5 9
#define LABEL_10_13 11
#define LABEL_10_10 13
#define LABEL_10_7 15
#define ENVIRONMENT_LABEL_10_3 30
#define DEBUGGING_LABEL_10_2 29
#define EXECUTE_CACHE_10_16 17
#define EXECUTE_CACHE_10_15 19
#define EXECUTE_CACHE_10_14 21
#define EXECUTE_CACHE_10_12 23
#define EXECUTE_CACHE_10_11 25
#define EXECUTE_CACHE_10_8 27
#define FREE_REFERENCES_LABEL_10_0 16
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto operation_read_finish_9;

    case 1:
      current_block = (Rpc - LABEL_10_6);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_10_9);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_10_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_10_13);
      goto loop_7;

    case 5:
      current_block = (Rpc - LABEL_10_10);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_10_7);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (operation_read_finish_12)
DEFLABEL (operation_read_finish_9)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  goto loop_7;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_10_5);

DEFLABEL (label_14)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_12]));

DEFLABEL (loop_13)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_10_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_14]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_10_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_10_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_15]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_10_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_16;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_7]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_10_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  Rsp = (& (Rsp [1]));
  goto loop_7;

DEFLABEL (label_15)
  (Wrd8.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_16]));

DEFLABEL (label_16)
  Rsp = (& (Rsp [2]));
  goto label_14;

DEFLABEL (label_17)
  Rsp = (& (Rsp [1]));
  goto label_14;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_7 5
#define LABEL_11_5 7
#define LABEL_11_9 9
#define ENVIRONMENT_LABEL_11_3 21
#define DEBUGGING_LABEL_11_2 20
#define OBJECT_11_2 19
#define OBJECT_11_1 18
#define OBJECT_11_0 17
#define EXECUTE_CACHE_11_10 11
#define EXECUTE_CACHE_11_8 13
#define EXECUTE_CACHE_11_6 15
#define FREE_REFERENCES_LABEL_11_0 10
#define NUMBER_OF_LINKER_SECTIONS_11_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd19;
  machine_word Wrd5;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto operation_discretionary_write_char_3;

    case 1:
      current_block = (Rpc - LABEL_11_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_11_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_11_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (operation_discretionary_write_char_7)
DEFLABEL (operation_discretionary_write_char_3)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_11_5);
  (Wrd5.Obj) = Rvl;
  (Wrd19.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd19.uLng) == 10))
    goto label_10;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_10;
  (Wrd7.Obj) = ((Wrd16.pObj) [5]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_9;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_11_2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_11_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_8;
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd29.Obj);
  (Rsp [1]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_8]));

DEFLABEL (label_10)
  (Wrd21.Obj) = (current_block [OBJECT_11_0]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_9]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 2);

DEFLABEL (label_5)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_5 5
#define ENVIRONMENT_LABEL_12_3 11
#define DEBUGGING_LABEL_12_2 10
#define OBJECT_12_0 9
#define EXECUTE_CACHE_12_6 7
#define FREE_REFERENCES_LABEL_12_0 6
#define NUMBER_OF_LINKER_SECTIONS_12_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto operation_clear_1;

    case 1:
      current_block = (Rpc - LABEL_12_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (operation_clear_4)
DEFLABEL (operation_clear_1)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_0]), 0);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_12_5);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_6]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define ENVIRONMENT_LABEL_13_3 11
#define DEBUGGING_LABEL_13_2 10
#define OBJECT_13_0 9
#define EXECUTE_CACHE_13_6 7
#define FREE_REFERENCES_LABEL_13_0 6
#define NUMBER_OF_LINKER_SECTIONS_13_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto operation_beep_1;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (operation_beep_4)
DEFLABEL (operation_beep_1)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_0]), 0);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_5);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_6]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define ENVIRONMENT_LABEL_14_3 6
#define DEBUGGING_LABEL_14_2 5
#define OBJECT_14_0 4
#define FREE_REFERENCES_LABEL_14_0 4
#define NUMBER_OF_LINKER_SECTIONS_14_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto operation_x_size_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (operation_x_size_3)
DEFLABEL (operation_x_size_0)
  INTERRUPT_CHECK (26, LABEL_14_4);
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 0);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define ENVIRONMENT_LABEL_15_3 6
#define DEBUGGING_LABEL_15_2 5
#define OBJECT_15_0 4
#define FREE_REFERENCES_LABEL_15_0 4
#define NUMBER_OF_LINKER_SECTIONS_15_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto operation_y_size_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (operation_y_size_3)
DEFLABEL (operation_y_size_0)
  INTERRUPT_CHECK (26, LABEL_15_4);
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_0]), 0);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define ENVIRONMENT_LABEL_16_3 9
#define DEBUGGING_LABEL_16_2 8
#define OBJECT_16_0 7
#define EXECUTE_CACHE_16_5 5
#define FREE_REFERENCES_LABEL_16_0 4
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
ttyio_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto operation_write_self_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (operation_write_self_3)
DEFLABEL (operation_write_self_0)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd5.Obj) = (current_block [OBJECT_16_0]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_5 5
#define LABEL_8 7
#define LABEL_9 9
#define LABEL_10 11
#define ENVIRONMENT_LABEL_3 30
#define DEBUGGING_LABEL_2 29
#define PURIFICATION_ROOT 28
#define OBJECT_10 27
#define OBJECT_9 26
#define OBJECT_8 25
#define OBJECT_7 24
#define OBJECT_6 23
#define OBJECT_5 22
#define OBJECT_4 21
#define OBJECT_3 20
#define OBJECT_2 19
#define OBJECT_1 18
#define OBJECT_0 17
#define GLOBAL_EXECUTE_CACHE_7 13
#define GLOBAL_EXECUTE_CACHE_6 15
#define FREE_REFERENCES_LABEL_0 12
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
ttyio_so_a0e77c2775bc2f38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_8);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_9);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_10);
      goto expression_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_4)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_9])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_8)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_7)
  {
    static const short sections [] =
      {
	0,
	1,
	0,
	0,
	1,
	1,
	1,
	1,
	1,
	2,
	2,
	1,
	2,
	2,
	0,
	3,
	0
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 16)
      goto label_6;
    blocks = (current_block [OBJECT_10]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_8])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_6)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd20.Obj) = (MAKE_OBJECT (0, 1));
  (Wrd21.Obj) = (current_block [OBJECT_1]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd5.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_7]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_7]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_ttyio_so_a0e77c2775bc2f38 [16] =
  {
    { "ttyio_so_code_1", 1, ttyio_so_code_1 },
    { "ttyio_so_code_2", 29, ttyio_so_code_2 },
    { "ttyio_so_code_3", 1, ttyio_so_code_3 },
    { "ttyio_so_code_4", 4, ttyio_so_code_4 },
    { "ttyio_so_code_5", 13, ttyio_so_code_5 },
    { "ttyio_so_code_6", 2, ttyio_so_code_6 },
    { "ttyio_so_code_7", 6, ttyio_so_code_7 },
    { "ttyio_so_code_8", 2, ttyio_so_code_8 },
    { "ttyio_so_code_9", 9, ttyio_so_code_9 },
    { "ttyio_so_code_10", 7, ttyio_so_code_10 },
    { "ttyio_so_code_11", 4, ttyio_so_code_11 },
    { "ttyio_so_code_12", 2, ttyio_so_code_12 },
    { "ttyio_so_code_13", 2, ttyio_so_code_13 },
    { "ttyio_so_code_14", 1, ttyio_so_code_14 },
    { "ttyio_so_code_15", 1, ttyio_so_code_15 },
    { "ttyio_so_code_16", 1, ttyio_so_code_16 }
  };

int
decl_ttyio_so_a0e77c2775bc2f38 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_ttyio_so_a0e77c2775bc2f38);
  return (0);
}

DECLARE_COMPILED_CODE ("ttyio.so", 5, decl_ttyio_so_a0e77c2775bc2f38, ttyio_so_a0e77c2775bc2f38)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_ttyio_so_data_a0e77c2775bc2f38 [2797] =
  "\x78\x22\xc5\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
  "\x2b\xb9\x1d\xb0\x82\x88\x0d\x0d\xba\x0d\x0d\x0d\x0d\xbb\x0d\x0d"
  "\x0d\x0d\x08\x0d\x0d\xbc\x25\x0d\xbd\x0d\x0d\xbe\x0d\x0d\xbf\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x0d\x1c\x0d\x1c\x0d\x0d\x1c\x24"
  "\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28"
  "\x0d\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x28\x0d\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x83\x88"
  "\xc2\x1c\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x84\x88\xc1\x0d\x1c"
  "\x24\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x85\x88\xc0\xb4\x24\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x0d\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x86\x88\x0d\x28\x0d\x28\x0d"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x0c\x1b"
  "\x0d\x1c\x1b\x0d\x1c\x25\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x24\x28\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0c\x81\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x0d\x28\xb3\x28\x0d\x28\xb2\x28\x1b\x28\x0d\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1d\x1b\x84\x28\x0d\x28\x0d\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xc0\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x02"
  "\x88\xc0\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xc0\x22\x29\x21\x9d\x2b\xba\x1d\xb0\x02\x88\xc0\x22\x29\x21"
  "\x9d\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b"
  "\x1c\x17\xb8\x88\xb0\xc3\x0d\x1b\x2a\x1b\x2a\xb2\x2a\x1b\x2a\xb3"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1e\x1e\x1e\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x1b\xb7\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\xb4\x0d\x1b\x1b\xb6\xb5\x0d\x0d\x17\x0d\x0c"
  "\x0d\x98\x84\x98\xb1\x2a\x85\x28\x0d\x28\x0d\x26\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x77\x2f\x61\x66\x73\x2f\x63"
  "\x73\x61\x69\x6c\x2e\x6d\x69\x74\x2e\x65\x64\x75\x2f\x67\x72\x6f"
  "\x75\x70\x2f\x6d\x61\x63\x2f\x70\x72\x6f\x6a\x65\x63\x74\x73\x2f"
  "\x73\x63\x68\x65\x6d\x65\x2f\x76\x37\x2f\x64\x69\x73\x74\x2f\x73"
  "\x6e\x61\x70\x73\x68\x6f\x74\x2e\x70\x6b\x67\x2f\x32\x30\x30\x37"
  "\x30\x39\x30\x39\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
  "\x63\x2d\x32\x30\x30\x37\x30\x39\x30\x39\x2f\x73\x72\x63\x2f\x72"
  "\x75\x6e\x74\x69\x6d\x65\x2f\x74\x74\x79\x69\x6f\x2e\x69\x6e\x66"
  "\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d"
  "\x72\x6f\x6f\x74\x5d\x02\x06\x04\x82\x02\x03\x02\x05\x62\x65\x65"
  "\x70\x0c\x63\x68\x61\x72\x2d\x72\x65\x61\x64\x79\x3f\x06\x63\x6c"
  "\x65\x61\x72\x19\x64\x69\x73\x63\x72\x65\x74\x69\x6f\x6e\x61\x72"
  "\x79\x2d\x77\x72\x69\x74\x65\x2d\x63\x68\x61\x72\x1b\x64\x69\x73"
  "\x63\x72\x65\x74\x69\x6f\x6e\x61\x72\x79\x2d\x66\x6c\x75\x73\x68"
  "\x2d\x6f\x75\x74\x70\x75\x74\x0a\x72\x65\x61\x64\x2d\x63\x68\x61"
  "\x72\x0c\x72\x65\x61\x64\x2d\x66\x69\x6e\x69\x73\x68\x0b\x77\x72"
  "\x69\x74\x65\x2d\x73\x65\x6c\x66\x07\x78\x2d\x73\x69\x7a\x65\x07"
  "\x79\x2d\x73\x69\x7a\x65\x08\x63\x68\x61\x6e\x6e\x65\x6c\x11\x74"
  "\x68\x65\x2d\x63\x6f\x6e\x73\x6f\x6c\x65\x2d\x70\x6f\x72\x74\x02"
  "\x13\x73\x61\x76\x65\x2d\x63\x6f\x6e\x73\x6f\x6c\x65\x2d\x69\x6e"
  "\x70\x75\x74\x12\x65\x76\x65\x6e\x74\x3a\x62\x65\x66\x6f\x72\x65"
  "\x2d\x65\x78\x69\x74\x0e\x72\x65\x73\x65\x74\x2d\x63\x6f\x6e\x73"
  "\x6f\x6c\x65\x14\x65\x76\x65\x6e\x74\x3a\x61\x66\x74\x65\x72\x2d"
  "\x72\x65\x73\x74\x6f\x72\x65\x11\x6f\x70\x65\x72\x61\x74\x69\x6f"
  "\x6e\x2f\x79\x2d\x73\x69\x7a\x65\x11\x6f\x70\x65\x72\x61\x74\x69"
  "\x6f\x6e\x2f\x78\x2d\x73\x69\x7a\x65\x09\x15\x6f\x70\x65\x72\x61"
  "\x74\x69\x6f\x6e\x2f\x77\x72\x69\x74\x65\x2d\x73\x65\x6c\x66\x0a"
  "\x16\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x2f\x72\x65\x61\x64\x2d"
  "\x66\x69\x6e\x69\x73\x68\x0b\x14\x6f\x70\x65\x72\x61\x74\x69\x6f"
  "\x6e\x2f\x72\x65\x61\x64\x2d\x63\x68\x61\x72\x0c\x18\x67\x65\x6e"
  "\x65\x72\x69\x63\x2d\x69\x6f\x2f\x66\x6c\x75\x73\x68\x2d\x6f\x75"
  "\x74\x70\x75\x74\x23\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x2f\x64"
  "\x69\x73\x63\x72\x65\x74\x69\x6f\x6e\x61\x72\x79\x2d\x77\x72\x69"
  "\x74\x65\x2d\x63\x68\x61\x72\x0d\x10\x6f\x70\x65\x72\x61\x74\x69"
  "\x6f\x6e\x2f\x63\x6c\x65\x61\x72\x0e\x17\x67\x65\x6e\x65\x72\x69"
  "\x63\x2d\x69\x6f\x2f\x63\x68\x61\x72\x2d\x72\x65\x61\x64\x79\x3f"
  "\x0f\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x2f\x62\x65\x65\x70\x0f"
  "\x0f\x04\x16\x67\x65\x6e\x65\x72\x69\x63\x2d\x69\x2f\x6f\x2d\x70"
  "\x6f\x72\x74\x2d\x74\x79\x70\x65\x04\x14\x61\x64\x64\x2d\x65\x76"
  "\x65\x6e\x74\x2d\x72\x65\x63\x65\x69\x76\x65\x72\x21\x02\x13\x74"
  "\x74\x79\x2d\x6f\x75\x74\x70\x75\x74\x2d\x63\x68\x61\x6e\x6e\x65"
  "\x6c\x10\x02\x12\x74\x74\x79\x2d\x69\x6e\x70\x75\x74\x2d\x63\x68"
  "\x61\x6e\x6e\x65\x6c\x11\x0c\x05\x6c\x69\x73\x74\x04\x0c\x6d\x61"
  "\x6b\x65\x2d\x63\x73\x74\x61\x74\x65\x12\x04\x0f\x6d\x61\x6b\x65"
  "\x2d\x70\x6f\x72\x74\x2d\x74\x79\x70\x65\x04\x12\x73\x65\x74\x2d"
  "\x63\x68\x61\x6e\x6e\x65\x6c\x2d\x70\x6f\x72\x74\x21\x13\x04\x0a"
  "\x6d\x61\x6b\x65\x2d\x70\x6f\x72\x74\x03\x16\x73\x65\x74\x2d\x63"
  "\x6f\x6e\x73\x6f\x6c\x65\x2d\x69\x2f\x6f\x2d\x70\x6f\x72\x74\x21"
  "\x14\x03\x18\x73\x65\x74\x2d\x63\x75\x72\x72\x65\x6e\x74\x2d\x69"
  "\x6e\x70\x75\x74\x2d\x70\x6f\x72\x74\x21\x03\x19\x73\x65\x74\x2d"
  "\x63\x75\x72\x72\x65\x6e\x74\x2d\x6f\x75\x74\x70\x75\x74\x2d\x70"
  "\x6f\x72\x74\x21\x0d\x23\x3c\x81\x89\x02\x22\x3a\x81\x89\x02\x21"
  "\x38\x81\x89\x02\x20\x36\x81\x89\x02\x1f\x34\x81\x89\x02\x1e\x32"
  "\x81\x8b\x02\x1d\x30\x81\x89\x02\x1c\x2e\x81\x8b\x02\x1b\x2c\x81"
  "\x87\x02\x1a\x2a\x81\x9f\x02\x19\x28\x81\x9d\x02\x18\x26\x81\x9b"
  "\x02\x17\x24\x81\x99\x02\x16\x22\x81\x97\x02\x15\x20\x81\x95\x02"
  "\x14\x1e\x81\x93\x02\x13\x1c\x81\x91\x02\x12\x1a\x81\x8f\x02\x11"
  "\x18\x81\x8d\x02\x10\x16\x81\x87\x02\x0f\x14\x81\x85\x02\x0e\x12"
  "\x81\x83\x02\x0d\x10\x81\x81\x02\x0c\x0e\x81\x81\x02\x0b\x0c\x81"
  "\x83\x02\x0a\x0a\x81\x85\x02\x09\x08\x81\x83\x02\x08\x06\x81\x81"
  "\x02\x07\x04\x82\x02\x3b\x74\x15\x02\x0b\x76\x65\x63\x74\x6f\x72"
  "\x2d\x72\x65\x66\x16\x24\x04\x83\x04\x03\x17\x02\x13\x72\x65\x6c"
  "\x6f\x61\x64\x2d\x73\x61\x76\x65\x2d\x73\x74\x72\x69\x6e\x67\x13"
  "\x63\x6f\x6e\x73\x6f\x6c\x65\x2d\x69\x6e\x70\x75\x74\x2d\x70\x6f"
  "\x72\x74\x18\x02\x03\x12\x70\x6f\x72\x74\x2d\x69\x6e\x70\x75\x74"
  "\x2d\x62\x75\x66\x66\x65\x72\x19\x03\x16\x69\x6e\x70\x75\x74\x2d"
  "\x62\x75\x66\x66\x65\x72\x2d\x63\x6f\x6e\x74\x65\x6e\x74\x73\x03"
  "\x28\x0a\x81\x83\x02\x27\x08\x81\x81\x02\x26\x06\x81\x85\x02\x25"
  "\x04\x82\x02\x09\x14\x1a\x02\x17\x72\x65\x6c\x6f\x61\x64\x2d\x72"
  "\x65\x74\x72\x69\x65\x76\x65\x2d\x73\x74\x72\x69\x6e\x67\x02\x02"
  "\x10\x02\x11\x04\x12\x04\x10\x73\x65\x74\x2d\x70\x6f\x72\x74\x2f"
  "\x73\x74\x61\x74\x65\x21\x03\x19\x04\x13\x04\x1b\x73\x65\x74\x2d"
  "\x69\x6e\x70\x75\x74\x2d\x62\x75\x66\x66\x65\x72\x2d\x63\x6f\x6e"
  "\x74\x65\x6e\x74\x73\x21\x08\x35\x1c\x81\x83\x02\x34\x1a\x81\x85"
  "\x02\x33\x18\x81\x85\x02\x32\x16\x81\x87\x02\x31\x14\x81\x85\x02"
  "\x30\x12\x81\x85\x02\x2f\x10\x81\x87\x02\x2e\x0e\x81\x89\x02\x2d"
  "\x0c\x81\x87\x02\x2c\x0a\x81\x85\x02\x2b\x08\x81\x83\x02\x2a\x06"
  "\x81\x81\x02\x29\x04\x82\x02\x1b\x30\x19\x02\x05\x74\x65\x78\x74"
  "\x03\x13\x63\x68\x61\x6e\x6e\x65\x6c\x2d\x74\x79\x70\x65\x3d\x66"
  "\x69\x6c\x65\x3f\x07\x0c\x6d\x61\x6b\x65\x2d\x67\x73\x74\x61\x74"
  "\x65\x03\x37\x06\x81\x8b\x02\x36\x04\x84\x06\x05\x0e\x13\x02\x08"
  "\x02\x09\x49\x2f\x4f\x20\x70\x6f\x72\x74\x14\x11\x63\x6f\x6e\x73"
  "\x6f\x6c\x65\x2d\x69\x2f\x6f\x2d\x70\x6f\x72\x74\x11\x18\x14\x63"
  "\x6f\x6e\x73\x6f\x6c\x65\x2d\x6f\x75\x74\x70\x75\x74\x2d\x70\x6f"
  "\x72\x74\x10\x04\x03\x0a\x69\x2f\x6f\x2d\x70\x6f\x72\x74\x3f\x05"
  "\x1a\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70"
  "\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x03\x3d\x0e\x81\x83\x02"
  "\x3c\x0c\x81\x83\x02\x3b\x0a\x81\x83\x02\x3a\x08\x81\x83\x02\x39"
  "\x06\x81\x83\x02\x38\x04\x83\x04\x0d\x1c\x1b\x02\x09\x11\x02\x04"
  "\x07\x70\x6f\x72\x74\x3d\x3f\x02\x3f\x06\x81\x85\x02\x3e\x04\x83"
  "\x04\x05\x0d\x1c\x02\x0a\x1d\x45\x6e\x64\x20\x6f\x66\x20\x69\x6e"
  "\x70\x75\x74\x20\x73\x74\x72\x65\x61\x6d\x20\x72\x65\x61\x63\x68"
  "\x65\x64\x2e\x03\x15\x67\x65\x6e\x65\x72\x69\x63\x2d\x69\x6f\x2f"
  "\x72\x65\x61\x64\x2d\x63\x68\x61\x72\x03\x0c\x65\x6f\x66\x2d\x6f"
  "\x62\x6a\x65\x63\x74\x3f\x1d\x02\x19\x6e\x65\x61\x72\x65\x73\x74"
  "\x2d\x63\x6d\x64\x6c\x2f\x62\x61\x74\x63\x68\x2d\x6d\x6f\x64\x65"
  "\x3f\x1e\x03\x0b\x66\x72\x65\x73\x68\x2d\x6c\x69\x6e\x65\x02\x17"
  "\x6e\x65\x61\x72\x65\x73\x74\x2d\x72\x65\x70\x6c\x2f\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x03\x11\x63\x6f\x6e\x64\x69\x74\x69\x6f"
  "\x6e\x2f\x65\x72\x72\x6f\x72\x3f\x02\x06\x25\x65\x78\x69\x74\x1f"
  "\x03\x1f\x04\x0d\x77\x72\x69\x74\x65\x2d\x73\x74\x72\x69\x6e\x67"
  "\x1f\x0a\x48\x14\x81\x85\x02\x47\x12\x81\x85\x02\x46\x10\x81\x87"
  "\x02\x45\x0e\x81\x85\x02\x44\x0c\x81\x85\x02\x43\x0a\x81\x85\x02"
  "\x42\x08\x81\x85\x02\x41\x06\x81\x83\x02\x40\x04\x83\x04\x13\x2b"
  "\x20\x02\x0b\x03\x11\x63\x68\x61\x72\x2d\x77\x68\x69\x74\x65\x73"
  "\x70\x61\x63\x65\x3f\x03\x03\x20\x6f\x75\x74\x70\x75\x74\x2d\x70"
  "\x6f\x72\x74\x2f\x64\x69\x73\x63\x72\x65\x74\x69\x6f\x6e\x61\x72"
  "\x79\x2d\x66\x6c\x75\x73\x68\x03\x03\x1d\x04\x0c\x75\x6e\x72\x65"
  "\x61\x64\x2d\x63\x68\x61\x72\x07\x4f\x10\x81\x83\x02\x4e\x0e\x81"
  "\x81\x02\x4d\x0c\x81\x81\x02\x4c\x0a\x81\x83\x02\x4b\x08\x81\x81"
  "\x02\x4a\x06\x81\x83\x02\x49\x04\x83\x04\x0f\x1f\x1d\x02\x0c\x02"
  "\x16\x03\x0b\x70\x6f\x72\x74\x2f\x73\x74\x61\x74\x65\x04\x17\x6f"
  "\x75\x74\x70\x75\x74\x2d\x70\x6f\x72\x74\x2f\x77\x72\x69\x74\x65"
  "\x2d\x63\x68\x61\x72\x02\x1e\x04\x53\x0a\x81\x85\x02\x52\x08\x81"
  "\x85\x02\x51\x06\x81\x85\x02\x50\x04\x84\x06\x09\x16\x1e\x02\x0d"
  "\x12\x74\x74\x79\x2d\x63\x6f\x6d\x6d\x61\x6e\x64\x2d\x63\x6c\x65"
  "\x61\x72\x04\x19\x6f\x75\x74\x70\x75\x74\x2d\x70\x6f\x72\x74\x2f"
  "\x77\x72\x69\x74\x65\x2d\x73\x74\x72\x69\x6e\x67\x16\x02\x55\x06"
  "\x81\x85\x02\x54\x04\x83\x04\x05\x0c\x02\x0e\x11\x74\x74\x79\x2d"
  "\x63\x6f\x6d\x6d\x61\x6e\x64\x2d\x62\x65\x65\x70\x04\x16\x02\x57"
  "\x06\x81\x85\x02\x56\x04\x83\x04\x05\x0c\x16\x02\x0f\x0b\x74\x74"
  "\x79\x2d\x78\x2d\x73\x69\x7a\x65\x58\x04\x83\x04\x03\x02\x10\x0b"
  "\x74\x74\x79\x2d\x79\x2d\x73\x69\x7a\x65\x59\x04\x83\x04\x03\x21"
  "\x02\x11\x0d\x20\x66\x6f\x72\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x04"
  "\x1f\x02\x5a\x04\x84\x06\x03\x0a\x1f\x11\x11\x6c\x6f\x63\x61\x6c"
  "\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0b\x72\x74\x64\x3a"
  "\x63\x73\x74\x61\x74\x65\x1f\x04\x21\x04\x04\x16\x04\x04\x1e\x04"
  "\x1d\x04\x20\x04\x1c\x04\x1b\x04\x13\x04\x19\x04\x1a\x04\x17\x04"
  "\x15\x04\x14\x0a\x09\x0f\x0e\x0d\x0b\x0c\x10\x18\x11\x12\x63\x6f"
  "\x6e\x73\x6f\x6c\x65\x2d\x69\x2f\x6f\x2d\x70\x6f\x72\x74\x3f\x14"
  "\x12\x13\x63\x73\x74\x61\x74\x65\x2d\x65\x63\x68\x6f\x2d\x69\x6e"
  "\x70\x75\x74\x3f\x14\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x2d"
  "\x70\x61\x63\x6b\x61\x67\x65\x21\x14\x07\x76\x65\x63\x74\x6f\x72"
  "\x07\x63\x73\x74\x61\x74\x65\x0c\x65\x63\x68\x6f\x2d\x69\x6e\x70"
  "\x75\x74\x3f\x04\x0a\x1b\x6d\x61\x6b\x65\x2d\x64\x65\x66\x69\x6e"
  "\x65\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x2d\x74\x79\x70\x65"
  "\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c"
  "\x65\x03\x05\x0c\x80\x80\x04\x04\x0a\x81\x81\x02\x03\x08\x81\x81"
  "\x02\x02\x06\x81\x85\x02\x01\x04\x81\x83\x02\x0b\x1f";

SCHEME_OBJECT *
ttyio_so_data_a0e77c2775bc2f38 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_ttyio_so_data_a0e77c2775bc2f38 [0]))), (sizeof (prog_ttyio_so_data_a0e77c2775bc2f38)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_10]));
}

DECLARE_COMPILED_DATA_NS ("ttyio.so", ttyio_so_data_a0e77c2775bc2f38)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("ttyio.so", "25cd59c241f83d25")
